@@ -10,5 +10,6 @@ from .actions_component import ResilientComponent
 from .action_message import ActionMessageBase, ActionMessage, \
     FunctionMessage, FunctionResult, FunctionError, \
     StatusMessage, BaseFunctionError
-from .decorators import function, handler, required_field, required_action_field, defer, debounce
-from .actions_test_component import SubmitTestAction, SubmitTestFunction
+from .decorators import function, inbound_app, app_function, handler, required_field, required_action_field, defer, debounce
+from .actions_test_component import SubmitTestAction, SubmitTestFunction, SubmitTestInboundApp
+from .app_function_component import AppFunctionComponent
